@@ -7,7 +7,8 @@ https://scraperwiki.com/docs/python/python_help_documentation/
 '''
 
 from .utils import scrape, pdftoxml, status
-import utils, sqlite
-
-sql = sqlite
+import utils
+import sql
 
+# Compatibility
+sqlite = sql
\ No newline at end of file
